Stan Math Library: stan/math/prim/mat/fun/rows_dot_product.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
rows_dot_product.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/err/check_matching_sizes.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R1, int C1, int R2, int C2>
Eigen::Matrix< double, R1, 1 > | stan::math::rows_dot_product (const Eigen::Matrix< double, R1, C1 > &v1, const Eigen::Matrix< double, R2, C2 > &v2)
| Returns the dot product of the specified vectors. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.